//
//  NanoVM, a tiny java VM for the Atmel AVR family
//  Copyright (C) 2005 by Till Harbaum <Till@Harbaum.org>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
// 

//
//  vm.h
//

#ifndef VM_H
#define VM_H

#include "heap.h"
#include "nvmfile.h"

// THE basic type
typedef s16_t vm_t;
typedef u16_t vmu_t;  // needed for >>> operator

// additional items to be allocated on heap during constructor call
#define VM_CLASS_CONST_ALLOC  1

// masks and bits of the basic type
#define IMMEDIATE_MASK  0x8000
#define TYPE_MASK       0xc000
#define TYPE_HEAP       0x8000
#define TYPE_CONST      0xc000

void   vm_init(void);
void   vm_run(u16_t mref);
bool_t vm_heap_id_in_use(heap_id_t id);

// expand types
vm_t   vm_expand(vm_t val);        // expand 15 bits into to 16 bits
vm_t   vm_byte_expand(vm_t val);   // expand byte to 16 bits
void   *vm_get_addr(u16_t ref);

// stack access used by native
void   vm_push(vm_t val);

vm_t   vm_pop(void);
vm_t   vm_peek(u08_t index);

vm_t   vm_pop_expand(void);
vm_t   vm_peek_expand(u08_t index);

void   *vm_pop_addr(void);
void   *vm_peek_addr(u08_t index);

#endif // VM_H
